@@ -298,15 +298,12 @@ def ET(root,screen,logfile,logfilename,
                                     contrib[0, thisCIS[0][0], k])
                         CD[k][1] = (CD[k][1] + mycontrib *
                                     contrib[0, thisCIS[1][0], k])
-                sign = ""
-                if thisCIS[2] < 0:
-                    sign = "-"
                 alphabeta = ["", ""]
                 if unres:
                     alphabeta = [["(A)", "(B)"][thisCIS[0][1]], ["(A)", "(B)"][thisCIS[1][1]]]
-                CIStext = "%s%s->%s%s (%s%d%%)" % (levelname(thisCIS[0][0], logfile.homos[thisCIS[0][1]]), alphabeta[0],
+                CIStext = "%s%s->%s%s (%d%%)" % (levelname(thisCIS[0][0], logfile.homos[thisCIS[0][1]]), alphabeta[0],
                                                    levelname(thisCIS[1][0], logfile.homos[thisCIS[1][1]]), alphabeta[1],
-                                                   sign, percontrib)                    
+                                                   percontrib)                    
                 if percontrib >= 10: # Major contributions (>=10%)
                     majorCIS[i].append(CIStext)
                 elif percontrib >= 2: #Minor contributions (>=2%)
@@ -396,18 +393,27 @@ def ET(root,screen,logfile,logfilename,
         elif len(logfile.etrotats)!=len(logfile.etenergies): # Catch violation of an assertion
             screen.write("The number of R values doesn't agree with the number of electronic transitions!\n")
             return False
+
+        # Equation 8 in Stephens, Harada, Chirality, 2010, 22, 229.
+        # This uses Delta, the half width at 1/e height.
+        # We use Sigma, the full width at 1/e height.
+        #   Delta = Sigma / 2
   
         endwaveno = convertor(start,"nm","cm-1")
         startwaveno = convertor(end,"nm","cm-1")
         sigma = convertor(FWHM, "eV", "cm-1")
-        prefactor = 1.0 / math.sqrt(2 * math.pi * sigma)
+        Delta = sigma / 2.
+
+        prefactor = 1.0 / (2.296e-39 * math.sqrt(math.pi) * Delta)
         peakmax = []
         for i in range(len(logfile.etrotats)):
-            peakmax.append((1/2.297e-39) * prefactor * logfile.etrotats[i] * logfile.etenergies[i] * 1e-40)
-
+            peakmax.append(prefactor * logfile.etrotats[i] *
+                           logfile.etenergies[i] * 1e-40)
+        # FWHM is sqrt(ln2) times sigma
+        real_FWHM = math.sqrt(math.log(2)) * sigma
         t = GaussianSpectrum(startwaveno,endwaveno,numpts,
                              ( logfile.etenergies,[peakmax] ),
-                             sigma)   
+                             real_FWHM)   
 
 ##        spectrum=[]
 ##        for x in range(numpts): # Spectrum from 10000 (1000nm) to 50000 cm-1 (200nm)
