@@ -280,7 +280,8 @@ class App:    # This sets up the GUI
             self.eddmbtn = Checkbutton(frame7, text="Create EDDM script?", variable=self.eddm)
             self.eddmbtn.pack(anchor=W)
             gaussdir = folder(self.screen, self.logfile.filename, create=False)
-            if (len(glob.glob(os.path.join(gaussdir, "*.fch"))) == 0 and
+            if (len(glob.glob(os.path.join(gaussdir, "*.fck"))) == 0 and
+                len(glob.glob(os.path.join(gaussdir, "*.fchk"))) == 0 and
                 len(glob.glob(os.path.join(gaussdir, "*.chk"))) == 0):
                 self.eddmbtn.configure(state=DISABLED)
 
